@@ -486,6 +486,11 @@ func runBazel(bazel string, args []string, out io.Writer) (int, error) {
 
 // getIncompatibleFlags returns all incompatible flags for the current Bazel command in alphabetical order.
 func getIncompatibleFlags(bazelPath, cmd string) ([]string, error) {
+	var incompatibleFlagsStr = GetEnvOrConfig("BAZELISK_INCOMPATIBLE_FLAGS")
+	if len(incompatibleFlagsStr) > 0 {
+		return strings.Split(incompatibleFlagsStr, ","), nil
+	}
+
 	out := strings.Builder{}
 	if _, err := runBazel(bazelPath, []string{"help", cmd, "--short"}, &out); err != nil {
 		return nil, fmt.Errorf("unable to determine incompatible flags with binary %s: %v", bazelPath, err)
